@@ -5,9 +5,10 @@ converting verse ids back into normalized references, and formatting
 references as human-readable strings.
 """
 
-__version__ = "0.2.2"
+__version__ = "0.4.0"
 
 from .bible.osis.parser import OSISParser
+from .book_groups import BOOK_GROUPS, BookGroup
 from .books import Book
 from .converter import (
     convert_reference_to_verse_ids,
@@ -16,6 +17,7 @@ from .converter import (
 )
 from .errors import (
     InvalidBibleParserError,
+    InvalidBookError,
     InvalidChapterError,
     InvalidVerseError,
     MissingBookFileError,
@@ -29,7 +31,8 @@ from .formatter import (
     get_parser,
     get_verse_text,
 )
-from .parser import NormalizedReference, get_references, normalize_reference
+from .normalized_reference import NormalizedReference
+from .parser import get_references, normalize_reference
 from .validator import (
     is_valid_book,
     is_valid_chapter,
